=====================================
numpydoc -- Numpy's Sphinx extensions
=====================================

.. image:: https://readthedocs.org/projects/numpydoc/badge/?version=latest
   :alt: Documentation Status
   :scale: 100%
   :target: https://numpydoc.readthedocs.io/en/latest/

.. image:: https://codecov.io/gh/numpy/numpydoc/branch/main/graph/badge.svg
   :target: https://app.codecov.io/gh/numpy/numpydoc/branch/main

.. image:: https://github.com/numpy/numpydoc/actions/workflows/test.yml/badge.svg?branch=main
   :target: https://github.com/numpy/numpydoc/actions/workflows/test.yml

This package provides the ``numpydoc`` Sphinx extension for handling
docstrings formatted according to the NumPy documentation format.
The extension also adds the code description directives
``np:function``, ``np-c:function``, etc.

numpydoc requires Python 3.8+ and sphinx 5+.

For usage information, please refer to the `documentation
<https://numpydoc.readthedocs.io/>`_.

The `numpydoc docstring guide
<https://numpydoc.readthedocs.io/en/latest/format.html>`_ explains how
to write docs formatted for this extension, and the `user guide
<https://numpydoc.readthedocs.io>`_ explains how to use it with Sphinx.
